@@ -1,14 +1,17 @@
+from __future__ import annotations
+
 import typing
+from typing_extensions import Literal, TypedDict
 
 
 ConfigSpec = dict
 ConfigData = typing.MutableMapping[str, typing.Any]
 
-ValidationOption = typing.Literal['raise', 'warn', False]
-OverwriteOption = typing.Literal[True, False, 'prompt']
+ValidationOption = Literal['raise', 'warn', False]
+OverwriteOption = Literal[True, False, 'prompt']
 
 
-class GetConfigKwargs(typing.TypedDict, total=False):
+class GetConfigKwargs(TypedDict, total=False):
     config_path_env_var: typing.Optional[str]
     config_path: typing.Optional[str]
     default_config_path: typing.Optional[str]
