@@ -50,7 +50,7 @@ def conforms_to_spec(
                 import pydantic
 
                 mode = 'pydantic'
-            except ImportError:
+            except (ImportError, AttributeError):
                 mode = 'dict'
         mode = 'dict'
 
@@ -78,7 +78,7 @@ def conforms_to_spec(
             import beartype
 
             @beartype.beartype
-            def validate_data(data: spec):
+            def validate_data(data: spec):  # type: ignore
                 return None
 
             try:
